@@ -82,9 +82,8 @@ crew_class_async <- R6::R6Class(
       private$.instance <- crew::crew_random_name()
       mirai::daemons(
         n = private$.workers,
-        dispatcher = FALSE,
+        dispatcher = "none",
         autoexit = crew_terminate_signal(),
-        resilience = FALSE,
         idletime = 60000,
         .compute = private$.instance
       )
