@@ -1,11 +1,3 @@
-crew_test("random_name()", {
-  out <- random_name()
-  expect_true(is.character(out))
-  expect_false(anyNA(out))
-  expect_equal(length(out), 1L)
-  expect_gt(nzchar(out), 0L)
-})
-
 crew_test("is_named", {
   expect_true(is_named(NULL))
   expect_true(is_named(list()))
@@ -15,6 +7,18 @@ crew_test("is_named", {
   expect_false(is_named(list(a = 1, 2)))
 })
 
+crew_test("parse_instance() with index ", {
+  socket <- "ws://10.0.0.9:56546/3/a6f9411a4b98c2e851f08387345c722597a9b5b7"
+  out <- parse_instance(socket)
+  expect_equal(out, "a6f9411a4b98c2e851f08387345c722597a9b5b7")
+})
+
+crew_test("parse_instance() without index ", {
+  socket <- "ws://10.0.0.9:56546/cba033e58a8561d7f49ab87d72b7ad86e28384de"
+  out <- parse_instance(socket)
+  expect_equal(out, "cba033e58a8561d7f49ab87d72b7ad86e28384de")
+})
+
 crew_test("eval_tidyselect()", {
   expr <- rlang::new_quosure(quote(tidyselect::any_of(c("b", "c"))))
   out <- eval_tidyselect(expr = expr, choices = letters[seq_len(4L)])
